@@ -36,19 +36,19 @@ use core::{
     assets::database::AssetsDatabase,
     ecs::{
         pipeline::{PipelineBuilder, PipelineBuilderError},
-        AccessType, ResQuery, ResRead, ResWrite,
+        AccessType, ResQuery, ResQueryItem, ResRead, ResWrite,
     },
     prefab::PrefabManager,
 };
 
-pub fn bundle_installer<Q, PB>(
+pub fn bundle_installer<PB, Q>(
     builder: &mut AppBuilder<PB>,
     user_interface: UserInterface,
 ) -> Result<(), PipelineBuilderError>
 where
-    Q: AccessType + ResQuery + 'static,
-    <Q as ResQuery>::Fetch: FeedProcessContext,
     PB: PipelineBuilder,
+    Q: AccessType + ResQuery + 'static,
+    ResQueryItem<Q>: FeedProcessContext,
 {
     builder.install_resource(user_interface);
     builder.install_resource(UserInterfaceSystemCache::default());
