@@ -21,7 +21,7 @@ impl ApplicationData {
 #[derive(Default)]
 pub struct UserInterface {
     pub(crate) data: HashMap<String, ApplicationData>,
-    pub(crate) setup: Option<fn(&mut Application)>,
+    pub(crate) setup_application: Option<fn(&mut Application)>,
     pub(crate) last_frame_captured: bool,
     pub pointer_axis_x: String,
     pub pointer_axis_y: String,
@@ -44,10 +44,10 @@ pub struct UserInterface {
 }
 
 impl UserInterface {
-    pub fn new(f: fn(&mut Application)) -> Self {
+    pub fn new(setup_application: fn(&mut Application)) -> Self {
         Self {
             data: Default::default(),
-            setup: Some(f),
+            setup_application: Some(setup_application),
             last_frame_captured: false,
             pointer_axis_x: Default::default(),
             pointer_axis_y: Default::default(),
